@@ -28,7 +28,12 @@ usage: $0 <options>
   Optional options:
      --doc-dir=DIR               path to install docs into [/usr/share/doc/kafka]
      --lib-dir=DIR               path to install Kafka home [/usr/lib/kafka]
-     --installed-lib-dir=DIR     path where lib-dir will end up on target system
+     --var-dir=DIR               path to install Kafka home [/var/lib/kafka]
+     --bin-dir=DIR               path to install bins [/usr/bin]
+     --man-dir=DIR               path to install mans [/usr/share/man]
+     --conf-dist-dir=DIR         path to install conf dist dir [/etc/kafka/conf.dist]
+     --etc-default=DIR           path to bigtop default dir [/etc/default]
+     --lib-zookeeper-dir=DIR     path to Zookeeper home [/usr/lib/zookeeper]
      --examples-dir=DIR          path to install examples [doc-dir/examples]
      ... [ see source for more similar options ]
   "
@@ -41,7 +46,12 @@ OPTS=$(getopt \
   -l 'prefix:' \
   -l 'doc-dir:' \
   -l 'lib-dir:' \
-  -l 'installed-lib-dir:' \
+  -l 'var-dir:' \
+  -l 'bin-dir:' \
+  -l 'man-dir:' \
+  -l 'conf-dist-dir:' \
+  -l 'etc-default:' \
+  -l 'lib-zookeeper-dir:' \
   -l 'source-dir:' \
   -l 'examples-dir:' \
   -l 'build-dir:' -- "$@")
@@ -68,6 +78,24 @@ while true ; do
         --lib-dir)
         LIB_DIR=$2 ; shift 2
         ;;
+        --var-dir)
+        VAR_DIR=$2 ; shift 2
+        ;;
+        --bin-dir)
+        BIN_DIR=$2 ; shift 2
+        ;;
+        --man-dir)
+        MAN_DIR=$2 ; shift 2
+        ;;
+        --conf-dist-dir)
+        CONF_DIST_DIR=$2 ; shift 2
+        ;;
+        --etc-default)
+        ETC_DEFAULT=$2 ; shift 2
+        ;;
+        --lib-zookeeper-dir)
+        LIB_ZOOKEEPER_DIR=$2 ; shift 2
+        ;;
         --examples-dir)
         EXAMPLES_DIR=$2 ; shift 2
         ;;
@@ -89,26 +117,28 @@ for var in PREFIX BUILD_DIR SOURCE_DIR; do
   fi
 done
 
-MAN_DIR=${MAN_DIR:-/usr/share/man/man1}
+MAN_DIR=${MAN_DIR:-/usr/share/man}/man1
 DOC_DIR=${DOC_DIR:-/usr/share/doc/kafka}
 LIB_DIR=${LIB_DIR:-/usr/lib/kafka}
+VAR_DIR=${VAR_DIR:-/var/lib/kafka}
+BIN_DIR=${BIN_DIR:-/usr/bin}
+ETC_DEFAULT=${ETC_DEFAULT:-/etc/default}
+LIB_ZOOKEEPER_DIR=${LIB_ZOOKEEPER_DIR:-/usr/lib/zookeeper}
 EXAMPLES_DIR=${EXAMPLES_DIR:-$DOC_DIR/examples}
-CONF_DIR=${CONF_DIR:-/etc/kafka/conf.dist}
-KAFKA_HOME=${KAFKA_HOME:-/usr/lib/kafka}
-ETC_KAFKA_DIR=${ETC_KAFKA_DIR:-/etc/kafka}
-BIN_DIR=/usr/bin
-INSTALLED_KAFKA_DIR=${LIB_DIR}
+
+CONF_DIR=/etc/kafka/conf
+CONF_DIST_DIR=${CONF_DIST_DIR:-/etc/kafka/conf.dist}
 
 install -d -m 0755 $PREFIX/$LIB_DIR
 install -d -m 0755 $PREFIX/$DOC_DIR
 install -d -m 0755 $PREFIX/$EXAMPLES_DIR
 
-install -d -m 0755 $PREFIX/var/lib/kafka/
+install -d -m 0755 $PREFIX/$VAR_DIR
 install -d -m 0755 $PREFIX/var/log/kafka/
 install -d -m 0755 $PREFIX/var/run/kafka/
 
 # Create the data directory.
-install -d -m 0755 $PREFIX/var/lib/kafka/data
+install -d -m 0755 $PREFIX/$VAR_DIR/data
 
 # Unzip binary tarball contents to lib directory.
 for jar in `ls ${BUILD_DIR}/build/kafka*.tgz | grep -v 'site-docs'`; do
@@ -145,30 +175,31 @@ do
 # Autodetect JAVA_HOME if not defined
 . /usr/lib/bigtop-utils/bigtop-detect-javahome
 
-exec $INSTALLED_KAFKA_DIR/bin/$file "\$@"
+exec $LIB_DIR/bin/$file "\$@"
 EOF
   chmod 755 $wrapper
 done
 
 # Copy in the configuration files
-install -d -m 0755 $PREFIX/$CONF_DIR
-cp -a ${BUILD_DIR}/config/{tools-log4j.properties,server.properties,log4j.properties} $PREFIX/$CONF_DIR/
+install -d -m 0755 $PREFIX/etc/kafka
+install -d -m 0755 $PREFIX/$CONF_DIST_DIR
+cp -a ${BUILD_DIR}/config/{tools-log4j.properties,server.properties,log4j.properties} $PREFIX/$CONF_DIST_DIR/
 # BIGTOP-1886
-sed -i -e "s|=log-cleaner.log|=$\{kafka.logs.dir\}/log-cleaner.log|" $PREFIX/$CONF_DIR/log4j.properties
-ln -s ${ETC_KAFKA_DIR}/conf $PREFIX/$LIB_DIR/config
+sed -i -e "s|=log-cleaner.log|=$\{kafka.logs.dir\}/log-cleaner.log|" $PREFIX/$CONF_DIST_DIR/log4j.properties
+ln -s $CONF_DIR $PREFIX/$LIB_DIR/config
 
 # Creating symlink to /var/log/kafka
 ln -s /var/log/kafka ${PREFIX}/$LIB_DIR/logs
 
 # Removing zookeeper*.jar from under libs and dropping a symlink in place
 rm -f ${PREFIX}/${LIB_DIR}/libs/zookeeper-*.jar
-ln -sf /usr/lib/zookeeper/zookeeper.jar ${PREFIX}/${LIB_DIR}/libs/
+ln -sf $LIB_ZOOKEEPER_DIR/zookeeper.jar ${PREFIX}/${LIB_DIR}/libs/
 
 # BIGTOP-3712
-ln -s /usr/lib/zookeeper/zookeeper-jute.jar ${PREFIX}/${LIB_DIR}/libs/
+ln -s $LIB_ZOOKEEPER_DIR/zookeeper-jute.jar ${PREFIX}/${LIB_DIR}/libs/
 
 # Copy in the defaults file
-install -d -m 0755 ${PREFIX}/etc/default
-cp ${SOURCE_DIR}/kafka.default ${PREFIX}/etc/default/kafka
+install -d -m 0755 $PREFIX/$ETC_DEFAULT
+cp ${SOURCE_DIR}/kafka.default $PREFIX/$ETC_DEFAULT/kafka
 
 cp ${BUILD_DIR}/{LICENSE,NOTICE} ${PREFIX}/${LIB_DIR}/
