@@ -22,14 +22,14 @@ if [ $# != 1 ]; then
   echo
   echo "Usage: build.sh <PREIX-OS-VERSION>"
   echo
-  echo "Example: build.sh trunk-centos-7"
-  echo "       : build.sh 1.0.0-centos-7"
+  echo "Example: build.sh trunk-ubuntu-22.04"
+  echo "       : build.sh 1.0.0-ubuntu-22.04"
   exit 1
 fi
 
 PREFIX=$(echo "$1" | cut -d '-' -f 1)
 OS=$(echo "$1" | cut -d '-' -f 2)
-VERSION=$(echo "$1" | cut -d '-' -f 3)
+VERSION=$(echo "$1" | cut -d '-' -f 3-)
 ARCH=$(uname -m)
 if [ "${ARCH}" != "x86_64" ];then
 ARCH="-${ARCH}"
@@ -53,15 +53,19 @@ EOF
 
 # modify the Dockerfile according to the OS/version
 case "${OS}-${VERSION}" in
-  fedora-36*)
+  fedora-38*)
     # use java 8 during build if the os's default java version is newer
     sed -i -e "s|RUN bash /tmp/puppetize.sh|ENV PATH /usr/lib/jvm/java-1.8.0/bin:\$PATH\nRUN bash /tmp/puppetize.sh|" Dockerfile
     # add initd
     sed -i -e "s|RUN bash /tmp/puppetize.sh|RUN bash /tmp/puppetize.sh\nRUN dnf install -y initscripts|" Dockerfile
     ;;
+  openeuler-22.03*)
+    OPENEULER_OS="${OS}/${OS}"
+    sed -i -e "s|${OS}:${VERSION}|$OPENEULER_OS:${VERSION}|" ./Dockerfile
+    ;;
   *)
     ;;
 esac
 
-docker build -t bigtop/puppet:${PREFIX}-${OS}-${VERSION}${ARCH} .
+docker build --no-cache -t bigtop/puppet:${PREFIX}-${OS}-${VERSION}${ARCH} .
 rm -f Dockerfile puppetize.sh
